@@ -155,3 +155,11 @@ class SnapReview(Review):
         if pat.search(n):
             return True
         return False
+
+    def _verify_appname(self, n):
+        '''Verify app name'''
+        pat = re.compile(r'^[a-zA-Z0-9][a-zA-Z0-9+-]+$')
+
+        if pat.search(n):
+            return True
+        return False
